@@ -2,9 +2,10 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 0, 8)
+__version__ = (0, 1)
 __all__ = [
-    "SupportsRead", "SupportsWrite", "SupportsSeek", 
+    "Buffer", "SupportsRead", "SupportsReadinto", 
+    "SupportsWrite", "SupportsSeek", 
     "bio_chunk_iter", "bio_chunk_async_iter", 
     "bio_skip_iter", "bio_skip_async_iter", 
     "bytes_iter_skip", "bytes_async_iter_skip", 
@@ -25,7 +26,39 @@ from typing import runtime_checkable, Any, Protocol, TypeVar
 try:
     from collections.abc import Buffer # type: ignore
 except ImportError:
-    Buffer = Any
+    from abc import ABC, abstractmethod
+    from array import array
+
+    def _check_methods(C, *methods):
+        mro = C.__mro__
+        for method in methods:
+            for B in mro:
+                if method in B.__dict__:
+                    if B.__dict__[method] is None:
+                        return NotImplemented
+                    break
+            else:
+                return NotImplemented
+        return True
+
+    class Buffer(ABC): # type: ignore
+        __slots__ = ()
+
+        @abstractmethod
+        def __buffer__(self, flags: int, /) -> memoryview:
+            raise NotImplementedError
+
+        @classmethod
+        def __subclasshook__(cls, C):
+            if cls is Buffer:
+                return _check_methods(C, "__buffer__")
+            return NotImplemented
+
+    Buffer.register(bytes)
+    Buffer.register(bytearray)
+    Buffer.register(memoryview)
+    Buffer.register(array)
+
 
 from asynctools import async_chain, ensure_async, ensure_aiter
 
@@ -39,6 +72,11 @@ class SupportsRead(Protocol[_T_co]):
     def read(self, /, __length: int = ...) -> _T_co: ...
 
 
+@runtime_checkable
+class SupportsReadinto(Protocol):
+    def readinto(self, /, buf: Buffer = ...) -> int: ...
+
+
 @runtime_checkable
 class SupportsWrite(Protocol[_T_contra]):
     def write(self, /, __s: _T_contra) -> object: ...
